==> rc-ui-lib-0.1.59.tgz: package/lib/grid/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _2 = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Grid', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render square grid with gutter correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              square: true,
              columnNum: 2,
              gutter: 10
            }, /*#__PURE__*/React().createElement(_2.default.Item, null), /*#__PURE__*/React().createElement(_2.default.Item, null), /*#__PURE__*/React().createElement(_2.default.Item, null)));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly with index prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              gutter: 10,
              columnNum: 4
            }, Array.from({
              length: 8
            }, function (_, i) {
              return /*#__PURE__*/React().createElement(_2.default.Item, {
                key: i,
                icon: "photo-o",
                text: "\u6587\u5B57"
              });
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should change icon size when using icon-size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              iconSize: "10"
            }, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "success"
            })));
            expect(wrapper.find('i').props().style.fontSize).toEqual('10px');

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should change icon color when using icon-color prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              iconSize: "10"
            }, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "success",
              iconColor: "red"
            })));
            expect(wrapper.find('i').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render icon correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              badge: {
                content: 1
              },
              icon: "success",
              iconColor: "red"
            })));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when icon is ReactNode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: /*#__PURE__*/React().createElement(_icon.default, {
                name: "shop-o"
              })
            })));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render ".rc-grid-item__content--reverse" class when using reverse prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              reverse: true
            }, /*#__PURE__*/React().createElement(_2.default.Item, null)));
            expect(wrapper.find('.rc-grid-item__content').hasClass('rc-grid-item__content--reverse')).toBeTruthy();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using text prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "hello,world!"
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when text prop is ReactNode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: /*#__PURE__*/React().createElement('div', {}, 'world')
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should render correctly when using iconPrefix prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee10() {
    return _regenerator().default.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              iconPrefix: "my-icon",
              text: "hello,world!"
            })));
            expect(wrapper.find('i').hasClass('my-icon-photo-o')).toBeTruthy();

          case 2:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('should render correctly when using iconColor prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee11() {
    return _regenerator().default.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              iconColor: "red"
            })));
            expect(wrapper.find('i').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('should render correctly when using contentClassName prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee12() {
    return _regenerator().default.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              contentClassName: "my-content"
            })));
            expect(wrapper.find('.my-content').exists()).toBeTruthy();

          case 2:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
  it('should render correctly when using contentStyle prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee13() {
    return _regenerator().default.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              contentStyle: {
                color: 'red'
              }
            })));
            expect(wrapper.find('.rc-grid-item__content').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context13.stop();
        }
      }
    }, _callee13);
  })));
  it('should emit click event correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee14() {
    var onClick;
    return _regenerator().default.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            onClick = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              onClick: onClick
            })));
            wrapper.find('.rc-grid-item__content').simulate('click');
            expect(onClick).toHaveBeenCalled();

          case 4:
          case "end":
            return _context14.stop();
        }
      }
    }, _callee14);
  })));
  it('should render correctly with children', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee15() {
    return _regenerator().default.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o"
            }, "hello,world!")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context15.stop();
        }
      }
    }, _callee15);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/lib/grid/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _2 = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Grid', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render square grid with gutter correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              square: true,
              columnNum: 2,
              gutter: 10
            }, /*#__PURE__*/React().createElement(_2.default.Item, null), /*#__PURE__*/React().createElement(_2.default.Item, null), /*#__PURE__*/React().createElement(_2.default.Item, null)));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly with index prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              gutter: 10,
              columnNum: 4
            }, Array.from({
              length: 8
            }, function (_, i) {
              return /*#__PURE__*/React().createElement(_2.default.Item, {
                key: i,
                icon: "photo-o",
                text: "\u6587\u5B57"
              });
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should change icon size when using icon-size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              iconSize: "10"
            }, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "success"
            })));
            expect(wrapper.find('i').props().style.fontSize).toEqual('10px');

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should change icon color when using icon-color prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              iconSize: "10"
            }, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "success",
              iconColor: "red"
            })));
            expect(wrapper.find('i').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render icon correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              badge: {
                content: 1
              },
              icon: "success",
              iconColor: "red"
            })));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when icon is ReactNode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: /*#__PURE__*/React().createElement(_icon.default, {
                name: "shop-o"
              })
            })));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render ".rc-grid-item__content--reverse" class when using reverse prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, {
              reverse: true
            }, /*#__PURE__*/React().createElement(_2.default.Item, null)));
            expect(wrapper.find('.rc-grid-item__content').hasClass('rc-grid-item__content--reverse')).toBeTruthy();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using text prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "hello,world!"
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when text prop is ReactNode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: /*#__PURE__*/React().createElement('div', {}, 'world')
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should render correctly when using iconPrefix prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee10() {
    return _regenerator().default.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              iconPrefix: "my-icon",
              text: "hello,world!"
            })));
            expect(wrapper.find('i').hasClass('my-icon-photo-o')).toBeTruthy();

          case 2:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('should render correctly when using iconColor prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee11() {
    return _regenerator().default.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              iconColor: "red"
            })));
            expect(wrapper.find('i').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('should render correctly when using contentClassName prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee12() {
    return _regenerator().default.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              contentClassName: "my-content"
            })));
            expect(wrapper.find('.my-content').exists()).toBeTruthy();

          case 2:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
  it('should render correctly when using contentStyle prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee13() {
    return _regenerator().default.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              contentStyle: {
                color: 'red'
              }
            })));
            expect(wrapper.find('.rc-grid-item__content').props().style.color).toEqual('red');

          case 2:
          case "end":
            return _context13.stop();
        }
      }
    }, _callee13);
  })));
  it('should emit click event correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee14() {
    var onClick;
    return _regenerator().default.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            onClick = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o",
              text: "picture",
              onClick: onClick
            })));
            wrapper.find('.rc-grid-item__content').simulate('click');
            expect(onClick).toHaveBeenCalled();

          case 4:
          case "end":
            return _context14.stop();
        }
      }
    }, _callee14);
  })));
  it('should render correctly with children', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee15() {
    return _regenerator().default.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_2.default, null, /*#__PURE__*/React().createElement(_2.default.Item, {
              icon: "photo-o"
            }, "hello,world!")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context15.stop();
        }
      }
    }, _callee15);
  })));
});
